==> z-web-support-0.1.5-sources.jar: cc/zuv/web/support/template/IWebTplCode.java <==
/*
 * Id$: zuv-cloud:z-web-support:cc.zuv.web.support.template.IWebTplCode:20190104094801
 *
 * IWebTplCode.java
 * Copyright (c) 2002-2020 Luther Inc.
 * http://zuv.cc
 * All rights reserved.
 */

package cc.zuv.web.support.template;

/**
 * zuv-cloud File Description
 *
 * @author          Kama Luther
 * @version         0.1
 * @since           0.1
 * @create.date     2019-01-04 09:47
 * @modify.date     2019-01-04 09:47
 */
public interface IWebTplCode
{

    //-----------------------------------------------------------------------------------------

    //----------------------------------------------------------------
    // 模板内置变量
    //----------------------------------------------------------------

    public static final String TPL_TAG_CONTEXT_HOST 	= "_content_host"; // 协议+主机+端口 http://192.168.31.129:8082
    public static final String TPL_TAG_CONTEXT_PATH 	= "_content_path"; // 全路径+参数 http://192.168.31.129:8082/inpress_index?a=1
    public static final String TPL_TAG_CONTEXT_URLS     = "_content_urls"; // 全路径 http://192.168.31.129:8082/inpress_index
    public static final String TPL_TAG_CONTEXT_BASE 	= "_content_base"; //

    //----------------------------------------------------------------
    //  模板变量定义
    //----------------------------------------------------------------

    public static final String TPL_KEY_ERRCODE				= "errcode";
    public static final String TPL_KEY_MESSAGE				= "message";
    public static final String TPL_KEY_STAMP				= "stamp";
    public static final String TPL_KEY_TITLE				= "title";
    public static final String TPL_KEY_CONTENT				= "content";

    //-----------------------------------------------------------------------------------------

}

==> z-web-support-0.1.9-sources.jar: cc/zuv/web/support/template/IWebTplCode.java <==
/*
 * Id$: zuv-cloud:z-web-support:cc.zuv.web.support.template.IWebTplCode:20190104094801
 *
 * IWebTplCode.java
 * Copyright (c) 2002-2020 Luther Inc.
 * http://zuv.cc
 * All rights reserved.
 */

package cc.zuv.web.support.template;

/**
 * zuv-cloud File Description
 *
 * @author          Kama Luther
 * @version         0.1
 * @since           0.1
 * @create.date     2019-01-04 09:47
 * @modify.date     2019-01-04 09:47
 */
public interface IWebTplCode
{

    //-----------------------------------------------------------------------------------------

    //----------------------------------------------------------------
    // 模板内置变量
    //----------------------------------------------------------------

    public static final String TPL_TAG_CONTEXT_HOST 	= "_content_host"; // 协议+主机+端口 http://192.168.31.129:8082
    public static final String TPL_TAG_CONTEXT_PATH 	= "_content_path"; // 全路径+参数 http://192.168.31.129:8082/inpress_index?a=1
    public static final String TPL_TAG_CONTEXT_URLS     = "_content_urls"; // 全路径 http://192.168.31.129:8082/inpress_index
    public static final String TPL_TAG_CONTEXT_BASE 	= "_content_base"; //

    //----------------------------------------------------------------
    //  模板变量定义
    //----------------------------------------------------------------

    public static final String TPL_KEY_ERRCODE				= "_errcode_";
    public static final String TPL_KEY_MESSAGE				= "_message_";
    public static final String TPL_KEY_STAMP				= "_stamp_";
    public static final String TPL_KEY_TITLE				= "_title_";
    public static final String TPL_KEY_CONTENT				= "_content_";

    //-----------------------------------------------------------------------------------------

}
